[elpa] externals/tramp 87c337e 1/2: * Makefile (sync): Add tramp-fuse.el and tramp-sshfs.el.

2021-03-30 Thread Michael Albinus
branch: externals/tramp
commit 87c337e03273ec4244664f3180d408253a136251
Author: Michael Albinus 
Commit: Michael Albinus 

* Makefile (sync): Add tramp-fuse.el and tramp-sshfs.el.
---
 Makefile | 2 ++
 1 file changed, 2 insertions(+)

diff --git a/Makefile b/Makefile
index 3199227..92d3c53 100644
--- a/Makefile
+++ b/Makefile
@@ -57,11 +57,13 @@ sync:
cp -p $(SOURCE_DIR)/lisp/tramp-compat.el tramp-compat.el
cp -p $(SOURCE_DIR)/lisp/tramp-crypt.el tramp-crypt.el
cp -p $(SOURCE_DIR)/lisp/tramp-ftp.el tramp-ftp.el
+   cp -p $(SOURCE_DIR)/lisp/tramp-fuse.el tramp-fuse.el
cp -p $(SOURCE_DIR)/lisp/tramp-gvfs.el tramp-gvfs.el
cp -p $(SOURCE_DIR)/lisp/tramp-integration.el tramp-integration.el
cp -p $(SOURCE_DIR)/lisp/tramp-rclone.el tramp-rclone.el
cp -p $(SOURCE_DIR)/lisp/tramp-sh.el tramp-sh.el
cp -p $(SOURCE_DIR)/lisp/tramp-smb.el tramp-smb.el
+   cp -p $(SOURCE_DIR)/lisp/tramp-sshfs.el tramp-sshfs.el
cp -p $(SOURCE_DIR)/lisp/tramp-sudoedit.el tramp-sudoedit.el
cp -p $(SOURCE_DIR)/lisp/tramp-uu.el tramp-uu.el
cp -p $(SOURCE_DIR)/lisp/tramp.el tramp.el



[elpa] externals/tramp 851269d 2/2: Tramp ELPA version 2.5.0.3 released

2021-03-30 Thread Michael Albinus
branch: externals/tramp
commit 851269dcfd7a564894ba4d4c2c7da8a97b40ce62
Author: Michael Albinus 
Commit: Michael Albinus 

Tramp ELPA version 2.5.0.3 released
---
 test/tramp-tests.el  |  84 ++-
 texi/tramp.texi  | 303 --
 texi/trampver.texi   |   2 +-
 tramp-adb.el |   2 -
 tramp-cache.el   |  28 ++--
 tramp-cmds.el|  17 ++-
 tramp-compat.el  |   2 +-
 tramp-crypt.el   |  24 +++
 tramp-fuse.el| 205 ++
 tramp-gvfs.el|   1 -
 tramp-integration.el |  24 ++-
 tramp-rclone.el  | 189 ++--
 tramp-sh.el  | 404 ++-
 tramp-smb.el |   7 -
 tramp-sshfs.el   | 367 ++
 tramp-sudoedit.el|  22 +--
 tramp.el | 164 -
 trampver.el  |   6 +-
 18 files changed, 1187 insertions(+), 664 deletions(-)

diff --git a/osc.el b/osc.el
index 28a1a5c..8be30ef 100644
--- a/osc.el
+++ b/osc.el
@@ -1,6 +1,6 @@
 ;;; osc.el --- Open Sound Control protocol library  -*- lexical-binding:t -*-
 
-;; Copyright (C) 2014-2020  Free Software Foundation, Inc.
+;; Copyright (C) 2014-2021  Free Software Foundation, Inc.
 
 ;; Author: Mario Lang 
 ;; Version: 0.2
@@ -173,6 +173,29 @@
 (expt 2.0 (- e 127))
 (1+ (/ f (expt 2.0 23
 
+(defun osc-read-float64 ()
+  (let ((s (lsh (logand (following-char) #X80) -7))
+   (e (+ (lsh (logand (following-char) #X7F) 4)
+ (lsh (logand (progn (forward-char) (following-char)) #XF0) -4)))
+   (f (+ (lsh (logand (following-char) #X0F) 48)
+ (lsh (progn (forward-char) (following-char)) 40)
+ (lsh (progn (forward-char) (following-char)) 32)
+ (lsh (progn (forward-char) (following-char)) 24)
+ (lsh (progn (forward-char) (following-char)) 16)
+ (lsh (progn (forward-char) (following-char)) 8)
+ (prog1 (progn (forward-char) (following-char)) (forward-char)
+(cond
+ ((and (= e 0) (= f 0))
+  (* 0.0 (expt -1 s)))
+ ((and (= e 2047) (or (= f (1- (expt 2 52))) (= f 0)))
+  (* 1.0e+INF (expt -1 s)))
+ ((and (= e 2047) (not (or (= f 0) (= f (1- (expt 2 52))
+  0.0e+NaN)
+ (t
+  (* (expt -1 s)
+(expt 2.0 (- e 1023))
+(1+ (/ f (expt 2.0 52
+
 (defun osc-server-set-handler (server path handler)
   "Set HANDLER for PATH on SERVER.
 IF HANDLER is nil, remove previously defined handler and fallback to
@@ -205,6 +228,7 @@ the generic handler for SERVER."
(lambda (type)
  (cl-case type
(?b (osc-read-blob))
+   (?d (osc-read-float64))
(?f (osc-read-float32))
(?i (osc-read-int32))
(?s (osc-read-string



[elpa] externals/company fe602f7: Don't try to render SVG icons in the terminal

2021-03-30 Thread ELPA Syncer
branch: externals/company
commit fe602f74283bd9537ddf04ef45d8e1b89b88e1be
Author: Dmitry Gutov 
Commit: Dmitry Gutov 

Don't try to render SVG icons in the terminal

#1082
---
 company.el | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/company.el b/company.el
index 434a3be..ac73a33 100644
--- a/company.el
+++ b/company.el
@@ -1406,7 +1406,8 @@ end of the match."
(integer :value 15
 
 (defun company--render-icons-margin (icon-mapping root-dir candidate selected)
-  (if-let ((candidate candidate)
+  (if-let ((ws (window-system))
+   (candidate candidate)
(kind (company-call-backend 'kind candidate))
(icon-file (alist-get kind icon-mapping)))
   (let* ((bkg (face-attribute (if selected



[elpa] externals/osc ef72809: Set binary coding for servers

2021-03-30 Thread Mario Lang
branch: externals/osc
commit ef72809f3d425e502a379790863bdb4a46ab4797
Author: Mario Lang 
Commit: Mario Lang 

Set binary coding for servers
---
 osc.el | 1 +
 1 file changed, 1 insertion(+)

diff --git a/osc.el b/osc.el
index 8be30ef..5a6a33d 100644
--- a/osc.el
+++ b/osc.el
@@ -249,6 +249,7 @@ fine grained control.
 A process object is returned which can be dicarded with `delete-process'."
   (make-network-process
:name "OSCserver"
+   :coding 'binary
:filter #'osc-filter
:host host
:service port



[elpa] externals/company 9bc678a: Remove elisp annotations when icons are used

2021-03-30 Thread ELPA Syncer
branch: externals/company
commit 9bc678a5c6627ea45853db38579fa67b2ad2863a
Author: Dmitry Gutov 
Commit: Dmitry Gutov 

Remove  elisp annotations when icons are used

#1070
---
 company-capf.el | 17 +
 1 file changed, 13 insertions(+), 4 deletions(-)

diff --git a/company-capf.el b/company-capf.el
index 496cd57..813b2aa 100644
--- a/company-capf.el
+++ b/company-capf.el
@@ -1,6 +1,6 @@
 ;;; company-capf.el --- company-mode completion-at-point-functions backend -*- 
lexical-binding: t -*-
 
-;; Copyright (C) 2013-2019  Free Software Foundation, Inc.
+;; Copyright (C) 2013-2019, 2021  Free Software Foundation, Inc.
 
 ;; Author: Stefan Monnier 
 
@@ -148,9 +148,7 @@ so we can't just use the preceding variable instead.")
  :company-location)))
(when f (funcall f arg
 (`annotation
- (let ((f (plist-get (nthcdr 4 company-capf--current-completion-data)
- :annotation-function)))
-   (when f (funcall f arg
+ (company-capf--annotation arg))
 (`kind
  (let ((f (plist-get (nthcdr 4 company-capf--current-completion-data)
  :company-kind)))
@@ -162,6 +160,17 @@ so we can't just use the preceding variable instead.")
  (company--capf-post-completion arg))
 ))
 
+(defun company-capf--annotation (arg)
+  (let* ((f (plist-get (nthcdr 4 company-capf--current-completion-data)
+   :annotation-function))
+ (annotation (when f (funcall f arg
+(if (and company-format-margin-function
+ (equal annotation " ") ; elisp-completion-at-point, pre-icons
+ (plist-get (nthcdr 4 company-capf--current-completion-data)
+:company-kind))
+nil
+  annotation)))
+
 (defun company-capf--candidates (input)
   (let ((res (company--capf-data)))
 (company-capf--save-current-data res)



[elpa] externals/dash b9286a8: Pacify uninitialized lexvar warnings in Emacs 28

2021-03-30 Thread ELPA Syncer
branch: externals/dash
commit b9286a84975874b10493f1cb4ea051c501f51273
Author: Basil L. Contovounesios 
Commit: Basil L. Contovounesios 

Pacify uninitialized lexvar warnings in Emacs 28

* dash.el (--reduce, --reductions-r): Pacify false positive warnings
in Emacs 28 about redundant nil-initialized lexical variables.

Fixes #377.
---
 dash.el | 8 ++--
 1 file changed, 6 insertions(+), 2 deletions(-)

diff --git a/dash.el b/dash.el
index 499a883..af22ef9 100644
--- a/dash.el
+++ b/dash.el
@@ -257,7 +257,9 @@ This is the anaphoric counterpart to `-reduce'."
 `(let ((,lv ,list))
(if ,lv
(--reduce-from ,form (car ,lv) (cdr ,lv))
- (let (acc it)
+ ;; Explicit nil binding pacifies lexical "variable left uninitialized"
+ ;; warning.  See issue #377 and upstream https://bugs.gnu.org/47080.
+ (let ((acc nil) (it nil))
(ignore acc it)
,form)
 
@@ -419,7 +421,9 @@ This is the anaphoric counterpart to `-reductions-r'."
(--reduce-from (cons (let ((acc (car acc))) (ignore acc) ,form) acc)
   (list (car ,lv))
   (cdr ,lv))
- (let (acc it)
+ ;; Explicit nil binding pacifies lexical "variable left uninitialized"
+ ;; warning.  See issue #377 and upstream https://bugs.gnu.org/47080.
+ (let ((acc nil) (it nil))
(ignore acc it)
(list ,form))
 



[elpa] externals/osc c916424: New function `osc-make-message'

2021-03-30 Thread Mario Lang
branch: externals/osc
commit c91642422eaea3cf4e7447e89a98dbe84f47e9a5
Author: Mario Lang 
Commit: Mario Lang 

New function `osc-make-message'
---
 osc.el | 33 +
 1 file changed, 25 insertions(+), 8 deletions(-)

diff --git a/osc.el b/osc.el
index 5a6a33d..daa0421 100644
--- a/osc.el
+++ b/osc.el
@@ -92,6 +92,13 @@
   (setq value (/ value 256)))
 (apply 'unibyte-string bytes)))
 
+(defun osc-timetag (time)
+  (cl-multiple-value-bind (high low usec psec) (time-convert time 'list)
+(concat (osc-int32 (+ 2208988800 (ash high 16) low))
+   (osc-int32 (round (* (+ (* usec (expt 10.0 -6))
+   (* psec (expt 10.0 -12)))
+(1- (ash 1 32
+
 ;;;###autoload
 (defun osc-make-client (host port)
   "Create an OSC client process which talks to HOST and PORT."
@@ -102,13 +109,12 @@
:service port
:type 'datagram))
 
-;;;###autoload
-(defun osc-send-message (client path &rest args)
-  "Send an OSC message from CLIENT to the specified PATH with ARGS."
-  (process-send-string
-   client
-   (apply
-'concat
+(defun osc-make-message (path &rest args)
+  "Make a OSC message with specified PATh and ARGS.
+A unibyte string is returned.  Use `vconcat' to convert that unibyte
+string to a vector if embedding in another OSC message is what you want."
+  (apply
+   'concat
 (osc-string path)
 (osc-string
  (apply
@@ -128,7 +134,12 @@
((integerp arg) (osc-int32 arg))
((stringp arg) (osc-string arg))
((vectorp arg) (osc-blob arg
- args
+ args)))
+
+;;;###autoload
+(defun osc-send-message (process path &rest args)
+  "Send an OSC message from PROCESS to the specified PATH with ARGS."
+  (process-send-string process (apply #'osc-make-message path args)))
 
 (defun osc-read-string ()
   (let ((pos (point)) string)
@@ -196,6 +207,12 @@
 (expt 2.0 (- e 1023))
 (1+ (/ f (expt 2.0 52
 
+(defun osc-read-timetag ()
+  (let ((secs (osc-read-int32))
+   (frac (osc-read-int32)))
+(time-convert (+ (- secs 2208988800)
+(/ (float frac) (1- (ash 1 32)))
+
 (defun osc-server-set-handler (server path handler)
   "Set HANDLER for PATH on SERVER.
 IF HANDLER is nil, remove previously defined handler and fallback to



[elpa] externals/posframe updated (fff21cc -> 320c035)

2021-03-30 Thread ELPA Syncer
elpasync pushed a change to branch externals/posframe.

  from  fff21cc   v0.8.8
   new  87407a2   * posframe.el (posframe-show): Add poshandler-extra-info 
argument.
   new  320c035   v0.9.0


Summary of changes:
 posframe.el | 55 +++
 1 file changed, 31 insertions(+), 24 deletions(-)



[elpa] externals/posframe 320c035 2/2: v0.9.0

2021-03-30 Thread ELPA Syncer
branch: externals/posframe
commit 320c0354280e0dbe2d7f9ca9bb066af257473372
Author: Feng Shu 
Commit: Feng Shu 

v0.9.0
---
 posframe.el | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/posframe.el b/posframe.el
index 14ac4e0..4901f71 100644
--- a/posframe.el
+++ b/posframe.el
@@ -5,7 +5,7 @@
 ;; Author: Feng Shu 
 ;; Maintainer: Feng Shu 
 ;; URL: https://github.com/tumashu/posframe
-;; Version: 0.8.8
+;; Version: 0.9.0
 ;; Keywords: convenience, tooltip
 ;; Package-Requires: ((emacs "26"))
 



[elpa] externals/posframe 87407a2 1/2: * posframe.el (posframe-show): Add poshandler-extra-info argument.

2021-03-30 Thread ELPA Syncer
branch: externals/posframe
commit 87407a2966db7161f26c92a1ff1c2fab6fbb00fd
Author: Feng Shu 
Commit: Feng Shu 

* posframe.el (posframe-show): Add poshandler-extra-info argument.
---
 posframe.el | 53 ++---
 1 file changed, 30 insertions(+), 23 deletions(-)

diff --git a/posframe.el b/posframe.el
index 7a5abf9..14ac4e0 100644
--- a/posframe.el
+++ b/posframe.el
@@ -378,6 +378,7 @@ This posframe's buffer is BUFFER-OR-NAME."
  string
  position
  poshandler
+ poshandler-extra-info
  width
  height
  min-width
@@ -472,6 +473,10 @@ by the way, poshandler can be used by other packages easily
  `((left . ,(car posn))
(top . ,(cdr posn
 
+POSHANDLER-EXTRA-INFO is a plist, which will prepend to the
+argument of poshandler function: 'info', it will *OVERRIDE* the
+exist key in 'info'.
+
 This posframe's buffer is BUFFER-OR-NAME, which can be a buffer
 or a name of a (possibly nonexistent) buffer.
 
@@ -542,6 +547,7 @@ The builtin hidehandler functions are listed below:
 You can use `posframe-delete-all' to delete all posframes."
   (let* ((position (or (funcall posframe-arghandler buffer-or-name :position 
position) (point)))
  (poshandler (funcall posframe-arghandler buffer-or-name :poshandler 
poshandler))
+ (poshandler-extra-info (funcall posframe-arghandler buffer-or-name 
:poshandler-extra-info poshandler-extra-info))
  (width (funcall posframe-arghandler buffer-or-name :width width))
  (height (funcall posframe-arghandler buffer-or-name :height height))
  (min-width (or (funcall posframe-arghandler buffer-or-name :min-width 
min-width) 1))
@@ -644,29 +650,30 @@ You can use `posframe-delete-all' to delete all 
posframes."
posframe
(posframe-run-poshandler
 ;; All poshandlers will get info from this plist.
-(list :position position
-  :position-info position-info
-  :poshandler poshandler
-  :font-height font-height
-  :font-width font-width
-  :posframe posframe
-  :posframe-width (frame-pixel-width posframe)
-  :posframe-height (frame-pixel-height posframe)
-  :posframe-buffer buffer
-  :parent-frame parent-frame
-  :parent-frame-width parent-frame-width
-  :parent-frame-height parent-frame-height
-  :parent-window parent-window
-  :parent-window-top parent-window-top
-  :parent-window-left parent-window-left
-  :parent-window-width parent-window-width
-  :parent-window-height parent-window-height
-  :mode-line-height mode-line-height
-  :minibuffer-height minibuffer-height
-  :header-line-height header-line-height
-  :tab-line-height tab-line-height
-  :x-pixel-offset x-pixel-offset
-  :y-pixel-offset y-pixel-offset))
+`(,@poshandler-extra-info
+  ,@(list :position position
+  :position-info position-info
+  :poshandler poshandler
+  :font-height font-height
+  :font-width font-width
+  :posframe posframe
+  :posframe-width (frame-pixel-width posframe)
+  :posframe-height (frame-pixel-height posframe)
+  :posframe-buffer buffer
+  :parent-frame parent-frame
+  :parent-frame-width parent-frame-width
+  :parent-frame-height parent-frame-height
+  :parent-window parent-window
+  :parent-window-top parent-window-top
+  :parent-window-left parent-window-left
+  :parent-window-width parent-window-width
+  :parent-window-height parent-window-height
+  :mode-line-height mode-line-height
+  :minibuffer-height minibuffer-height
+  :header-line-height header-line-height
+  :tab-line-height tab-line-height
+  :x-pixel-offset x-pixel-offset
+  :y-pixel-offset y-pixel-offset)))
parent-frame-width parent-frame-height)
 
   ;; Delay hide posframe when timeout is a number.



[elpa] externals/org 6a50e41 1/3: org-agenda.el: Rename org-agenda-format-item parameters

2021-03-30 Thread ELPA Syncer
branch: externals/org
commit 6a50e41ea5a0bc7ef0f591e000269e6c0485f09e
Author: Renato Ferreira 
Commit: Kyle Meyer 

org-agenda.el: Rename org-agenda-format-item parameters

* org-agenda.el (org-agenda-format-item): Rename parameters so they
don't clash with dynamic variables used by
`org-prefix-format-compiled'.

TINYCHANGE
---
 lisp/org-agenda.el | 10 +-
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/lisp/org-agenda.el b/lisp/org-agenda.el
index 33b3786..f22e6fa 100644
--- a/lisp/org-agenda.el
+++ b/lisp/org-agenda.el
@@ -6654,14 +6654,14 @@ The flag is set if the currently compiled format 
contains a `%b'.")
  (cl-return (cadr entry))
(cl-return (apply #'create-image (cdr entry)))
 
-(defun org-agenda-format-item (extra txt &optional level category tags dotime
+(defun org-agenda-format-item (extra txt &optional with-level with-category 
tags dotime
 remove-re habitp)
   "Format TXT to be inserted into the agenda buffer.
 In particular, add the prefix and corresponding text properties.
 
 EXTRA must be a string to replace the `%s' specifier in the prefix format.
-LEVEL may be a string to replace the `%l' specifier.
-CATEGORY (a string, a symbol or nil) may be used to overrule the default
+WITH-LEVEL may be a string to replace the `%l' specifier.
+WITH-CATEGORY (a string, a symbol or nil) may be used to overrule the default
 category taken from local variable or file name.  It will replace the `%c'
 specifier in the format.
 DOTIME, when non-nil, indicates that a time-of-day should be extracted from
@@ -6698,7 +6698,7 @@ Any match of REMOVE-RE will be removed from TXT."
 (defvar breadcrumbs) (defvar category) (defvar category-icon)
 (defvar effort) (defvar extra)
 (defvar level) (defvar tag) (defvar time))
-  (let* ((category (or category
+  (let* ((category (or with-category
   (if buffer-file-name
   (file-name-sans-extension
(file-name-nondirectory buffer-file-name))
@@ -6796,7 +6796,7 @@ Any match of REMOVE-RE will be removed from TXT."
 time-grid-trailing-characters)))
 (t ""))
  category (if (symbolp category) (symbol-name category) category)
- level (or level ""))
+ level (or with-level ""))
(if (string-match org-link-bracket-re category)
(progn
  (setq l (string-width (or (match-string 2) (match-string 1



[elpa] externals-release/org updated (7c23fc7 -> 1c0ce74)

2021-03-30 Thread ELPA Syncer
elpasync pushed a change to branch externals-release/org.

  from  7c23fc7   ob-ocaml: Update stale tuareg-mode link in commentary
   new  d017cdb   NEWS: Group and move up electric-indent/adapt-indentation 
entries
   new  1c0ce74   NEWS: Remove quote from in front of headline-data symbol


Summary of changes:
 etc/ORG-NEWS | 68 ++--
 1 file changed, 34 insertions(+), 34 deletions(-)



[elpa] externals-release/org d017cdb 1/2: NEWS: Group and move up electric-indent/adapt-indentation entries

2021-03-30 Thread ELPA Syncer
branch: externals-release/org
commit d017cdb0aee24b4c9e5017f76019d3cc1ccfe4bd
Author: Kyle Meyer 
Commit: Kyle Meyer 

NEWS: Group and move up electric-indent/adapt-indentation entries

Put the entry for "respecting electric-indent-mode" and the new value
of org-adapt-indentation near each other given that honoring
electric-indent-mode is likely to make many users aware of the
behavior that org-adapt-indentation controls (even if they weren't
aware that the option existed).

Also move these entries up in hopes of making them easier to discover.

Suggested-by: Tim Cross 
Ref: https://orgmode.org/list/87pmzhi7wp@gmail.com
---
 etc/ORG-NEWS | 68 ++--
 1 file changed, 34 insertions(+), 34 deletions(-)

diff --git a/etc/ORG-NEWS b/etc/ORG-NEWS
index 2e3ce50..71ce674 100644
--- a/etc/ORG-NEWS
+++ b/etc/ORG-NEWS
@@ -102,6 +102,40 @@ Also, ~org-startup-folded~ now defaults to 
~showeverything~.
 
 ** New features
 
+*** =RET= and =C-j= now obey ~electric-indent-mode~
+
+Since Emacs 24.4, ~electric-indent-mode~ is enabled by default.  In
+most major modes, this causes =RET= to reindent the current line and
+indent the new line, and =C-j= to insert a newline without indenting.
+
+Org mode now obeys this minor mode: when ~electric-indent-mode~ is
+enabled, and point is neither in a table nor on a timestamp or a link:
+
+- =RET= (bound to ~org-return~) reindents the current line and indents
+  the new line;
+- =C-j= (bound to the new command ~org-return-and-maybe-indent~)
+  merely inserts a newline.
+
+To get the previous behaviour back, disable ~electric-indent-mode~
+explicitly:
+
+#+begin_src emacs-lisp
+(add-hook 'org-mode-hook (lambda () (electric-indent-local-mode -1)))
+#+end_src
+
+Alternatively, if you wish to keep =RET= as the "smart-return" key,
+but dislike Org's default indentation of sections, you may prefer to
+customize ~org-adapt-indentation~ to either =nil= or ='headline-data=.
+
+*** New allowed value for ~org-adapt-indentation~
+
+~org-adapt-indentation~ now accepts a new value, ='headline-data=.
+
+When set to this value, Org will only adapt indentation of headline
+data lines, such as planning/clock lines and property/logbook drawers.
+Also, with this setting, =org-indent-mode= will keep these data lines
+correctly aligned with the headline above.
+
 *** Looping agenda commands over headlines
 
 ~org-agenda-loop-over-headlines-in-active-region~ allows you to loop
@@ -135,15 +169,6 @@ call ~org-toggle-radio-button~.
 You can also add =#+ATTR_ORG: :radio t= right before the list to tell
 Org to use radio buttons for this list only.
 
-*** New allowed value for ~org-adapt-indentation~
-
-~org-adapt-indentation~ now accepts a new value, ='headline-data=.
-
-When set to this value, Org will only adapt indentation of headline
-data lines, such as planning/clock lines and property/logbook drawers.
-Also, with this setting, =org-indent-mode= will keep these data lines
-correctly aligned with the headline above.
-
 *** Numeric priorities are now allowed (up to 65)
 
 You can now set ~org-priority-highest/lowest/default~ to integers to
@@ -213,31 +238,6 @@ can now be inserted with this prefix argument.
 Source code block header argument =:file-mode= can set file
 permissions if =:file= argument is provided.
 
-*** =RET= and =C-j= now obey ~electric-indent-mode~
-
-Since Emacs 24.4, ~electric-indent-mode~ is enabled by default.  In
-most major modes, this causes =RET= to reindent the current line and
-indent the new line, and =C-j= to insert a newline without indenting.
-
-Org mode now obeys this minor mode: when ~electric-indent-mode~ is
-enabled, and point is neither in a table nor on a timestamp or a link:
-
-- =RET= (bound to ~org-return~) reindents the current line and indents
-  the new line;
-- =C-j= (bound to the new command ~org-return-and-maybe-indent~)
-  merely inserts a newline.
-
-To get the previous behaviour back, disable ~electric-indent-mode~
-explicitly:
-
-#+begin_src emacs-lisp
-(add-hook 'org-mode-hook (lambda () (electric-indent-local-mode -1)))
-#+end_src
-
-Alternatively, if you wish to keep =RET= as the "smart-return" key,
-but dislike Org's default indentation of sections, you may prefer to
-customize ~org-adapt-indentation~ to either =nil= or ='headline-data=.
-
 *** =ob-C.el= allows the inclusion of non-system header files
 
 In C and C++ blocks, ~:includes~ arguments that do not start with a



[elpa] externals/org 3089fcd 2/3: Remove redundant #' around lambdas

2021-03-30 Thread ELPA Syncer
branch: externals/org
commit 3089fcd6908d18919af2bb2e818c39a7a91581c7
Author: Stefan Kangas 
Commit: Kyle Meyer 

Remove redundant #' around lambdas

* contrib/lisp/org-choose.el (org-choose-get-highest-mark-index)
(org-choose-get-fn-map-group, org-choose-keep-sensible)
(org-choose-setup-vars):
* lisp/org-mouse.el (org-mode-hook, org-mouse-context-menu)
(org-mouse-popup-global-menu):
* lisp/ox-beamer.el (org-beamer--format-section):
* lisp/ox.el (org-export-insert-default-template): Remove redundant #'
around lambdas.
---
 contrib/lisp/org-choose.el |  36 ++---
 lisp/org-mouse.el  | 130 ++---
 lisp/ox-beamer.el  |   2 +-
 lisp/ox.el |   2 +-
 4 files changed, 85 insertions(+), 85 deletions(-)

diff --git a/contrib/lisp/org-choose.el b/contrib/lisp/org-choose.el
index c791a86..839a38b 100644
--- a/contrib/lisp/org-choose.el
+++ b/contrib/lisp/org-choose.el
@@ -175,8 +175,8 @@ Each entry is an `org-choose-mark-data.'" )
   (pushnew (cons text tail)
   org-choose-mark-data
   :test
-  #'(lambda (a b)
-  (equal (car a) (car b)))
+   (lambda (a b)
+ (equal (car a) (car b)))
 
 ;;; org-choose-filter-tail
 (defun org-choose-filter-tail (raw)
@@ -347,8 +347,8 @@ setting was changed."
   org-todo-log-states)
;;Map over group
(funcall map-over-entries
-#'(lambda ()
-(apply func-d473 args-46k
+ (lambda ()
+   (apply func-d473 args-46k
 ;;Remove the marker
 (set-marker entry-pos nil)))
 
@@ -371,18 +371,18 @@ setting was changed."
 
 (defun org-choose-get-fn-map-group ()
   "Return a function to map over the group"
-  #'(lambda (fn)
-  (require 'org-agenda) ;; `org-map-entries' seems to need it.
-  (save-excursion
-   (unless (org-up-heading-safe)
- (error "Choosing is only supported between siblings in a tree, not on 
top level"))
-   (let
-   ((level (org-reduced-level (org-outline-level
- (save-restriction
-   (org-map-entries
-fn
-(format "LEVEL=%d" level)
-'tree))
+  (lambda (fn)
+(require 'org-agenda) ;; `org-map-entries' seems to need it.
+(save-excursion
+  (unless (org-up-heading-safe)
+(error "Choosing is only supported between siblings in a tree, not on 
top level"))
+  (let
+  ((level (org-reduced-level (org-outline-level
+(save-restriction
+  (org-map-entries
+   fn
+   (format "LEVEL=%d" level)
+   'tree))
 
 ;;; org-choose-get-highest-mark-index
 
@@ -396,8 +396,8 @@ If there is none, return 0"
(indexes-list
(remove nil
(funcall map-over-entries
-#'(lambda ()
-(org-choose-get-entry-index keywords))
+ (lambda ()
+   (org-choose-get-entry-index keywords))
 (if
indexes-list
(apply #'max indexes-list)
diff --git a/lisp/org-mouse.el b/lisp/org-mouse.el
index 5c222ea..32897e6 100644
--- a/lisp/org-mouse.el
+++ b/lisp/org-mouse.el
@@ -501,7 +501,7 @@ SCHEDULED: or DEADLINE: or ANYTHINGLIKETHIS:"
  ("Check Tags"
   ,@(org-mouse-keyword-menu
 (sort (mapcar 'car (org-get-buffer-tags)) 'string-lessp)
-#'(lambda (tag) (org-tags-sparse-tree nil tag)))
+ (lambda (tag) (org-tags-sparse-tree nil tag)))
   "--"
   ["Custom Tag ..." org-tags-sparse-tree t])
  ["Check Phrase ..." org-occur]
@@ -511,26 +511,26 @@ SCHEDULED: or DEADLINE: or ANYTHINGLIKETHIS:"
  ("Display Tags"
   ,@(org-mouse-keyword-menu
 (sort (mapcar 'car (org-get-buffer-tags)) 'string-lessp)
-#'(lambda (tag) (org-tags-view nil tag)))
+ (lambda (tag) (org-tags-view nil tag)))
   "--"
   ["Custom Tag ..." org-tags-view t])
  ["Display Calendar" org-goto-calendar t]
  "--"
  ,@(org-mouse-keyword-menu
(mapcar 'car org-agenda-custom-commands)
-   #'(lambda (key)
-   (eval `(org-agenda nil (string-to-char ,key
+(lambda (key)
+  (eval `(org-agenda nil (string-to-char ,key
nil
-   #'(lambda (key)
-   (let ((entry (assoc key org-agenda-custom-commands)))
- (org-mouse-clip-text
-  (cond
-   ((stringp (nth 1 entry)) (nth 1 entry))
-   ((stringp (nth 2 entry))
-(concat (org-mouse-agenda-type (nth 1 entry))
-(nth 2 entry)))
-   (t "Agenda Command `%s'"))
-  30
+(lambda (key)
+  (let ((entry (assoc key org-agenda-custom-commands)))
+(org-mouse-clip-text
+

[elpa] externals/org f03cba1 3/3: Merge branch 'maint'

2021-03-30 Thread ELPA Syncer
branch: externals/org
commit f03cba1b6f60738f7c3158e8296d2d06fd31cc78
Merge: 3089fcd 1c0ce74
Author: Kyle Meyer 
Commit: Kyle Meyer 

Merge branch 'maint'
---
 etc/ORG-NEWS | 68 ++--
 1 file changed, 34 insertions(+), 34 deletions(-)

diff --git a/etc/ORG-NEWS b/etc/ORG-NEWS
index 6e3c06f..8bf3a7d 100644
--- a/etc/ORG-NEWS
+++ b/etc/ORG-NEWS
@@ -319,6 +319,40 @@ Also, ~org-startup-folded~ now defaults to 
~showeverything~.
 
 ** New features
 
+*** =RET= and =C-j= now obey ~electric-indent-mode~
+
+Since Emacs 24.4, ~electric-indent-mode~ is enabled by default.  In
+most major modes, this causes =RET= to reindent the current line and
+indent the new line, and =C-j= to insert a newline without indenting.
+
+Org mode now obeys this minor mode: when ~electric-indent-mode~ is
+enabled, and point is neither in a table nor on a timestamp or a link:
+
+- =RET= (bound to ~org-return~) reindents the current line and indents
+  the new line;
+- =C-j= (bound to the new command ~org-return-and-maybe-indent~)
+  merely inserts a newline.
+
+To get the previous behaviour back, disable ~electric-indent-mode~
+explicitly:
+
+#+begin_src emacs-lisp
+(add-hook 'org-mode-hook (lambda () (electric-indent-local-mode -1)))
+#+end_src
+
+Alternatively, if you wish to keep =RET= as the "smart-return" key,
+but dislike Org's default indentation of sections, you may prefer to
+customize ~org-adapt-indentation~ to either =nil= or =headline-data=.
+
+*** New allowed value for ~org-adapt-indentation~
+
+~org-adapt-indentation~ now accepts a new value, =headline-data=.
+
+When set to this value, Org will only adapt indentation of headline
+data lines, such as planning/clock lines and property/logbook drawers.
+Also, with this setting, =org-indent-mode= will keep these data lines
+correctly aligned with the headline above.
+
 *** Looping agenda commands over headlines
 
 ~org-agenda-loop-over-headlines-in-active-region~ allows you to loop
@@ -352,15 +386,6 @@ call ~org-toggle-radio-button~.
 You can also add =#+ATTR_ORG: :radio t= right before the list to tell
 Org to use radio buttons for this list only.
 
-*** New allowed value for ~org-adapt-indentation~
-
-~org-adapt-indentation~ now accepts a new value, ='headline-data=.
-
-When set to this value, Org will only adapt indentation of headline
-data lines, such as planning/clock lines and property/logbook drawers.
-Also, with this setting, =org-indent-mode= will keep these data lines
-correctly aligned with the headline above.
-
 *** Numeric priorities are now allowed (up to 65)
 
 You can now set ~org-priority-highest/lowest/default~ to integers to
@@ -430,31 +455,6 @@ can now be inserted with this prefix argument.
 Source code block header argument =:file-mode= can set file
 permissions if =:file= argument is provided.
 
-*** =RET= and =C-j= now obey ~electric-indent-mode~
-
-Since Emacs 24.4, ~electric-indent-mode~ is enabled by default.  In
-most major modes, this causes =RET= to reindent the current line and
-indent the new line, and =C-j= to insert a newline without indenting.
-
-Org mode now obeys this minor mode: when ~electric-indent-mode~ is
-enabled, and point is neither in a table nor on a timestamp or a link:
-
-- =RET= (bound to ~org-return~) reindents the current line and indents
-  the new line;
-- =C-j= (bound to the new command ~org-return-and-maybe-indent~)
-  merely inserts a newline.
-
-To get the previous behaviour back, disable ~electric-indent-mode~
-explicitly:
-
-#+begin_src emacs-lisp
-(add-hook 'org-mode-hook (lambda () (electric-indent-local-mode -1)))
-#+end_src
-
-Alternatively, if you wish to keep =RET= as the "smart-return" key,
-but dislike Org's default indentation of sections, you may prefer to
-customize ~org-adapt-indentation~ to either =nil= or ='headline-data=.
-
 *** =ob-C.el= allows the inclusion of non-system header files
 
 In C and C++ blocks, ~:includes~ arguments that do not start with a



[elpa] externals-release/org 1c0ce74 2/2: NEWS: Remove quote from in front of headline-data symbol

2021-03-30 Thread ELPA Syncer
branch: externals-release/org
commit 1c0ce74a1f91360a4daaaed26cb135add5144c34
Author: Kyle Meyer 
Commit: Kyle Meyer 

NEWS: Remove quote from in front of headline-data symbol

There's no need to quote the symbol when referring to it, just as
`symbol' rather than `'symbol' is used in docstrings.
---
 etc/ORG-NEWS | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/etc/ORG-NEWS b/etc/ORG-NEWS
index 71ce674..ca862a2 100644
--- a/etc/ORG-NEWS
+++ b/etc/ORG-NEWS
@@ -125,11 +125,11 @@ explicitly:
 
 Alternatively, if you wish to keep =RET= as the "smart-return" key,
 but dislike Org's default indentation of sections, you may prefer to
-customize ~org-adapt-indentation~ to either =nil= or ='headline-data=.
+customize ~org-adapt-indentation~ to either =nil= or =headline-data=.
 
 *** New allowed value for ~org-adapt-indentation~
 
-~org-adapt-indentation~ now accepts a new value, ='headline-data=.
+~org-adapt-indentation~ now accepts a new value, =headline-data=.
 
 When set to this value, Org will only adapt indentation of headline
 data lines, such as planning/clock lines and property/logbook drawers.



[elpa] externals/org updated (4d9dabc -> f03cba1)

2021-03-30 Thread ELPA Syncer
elpasync pushed a change to branch externals/org.

  from  4d9dabc   Merge branch 'maint'
   new  6a50e41   org-agenda.el: Rename org-agenda-format-item parameters
   new  3089fcd   Remove redundant #' around lambdas
   new  d017cdb   NEWS: Group and move up electric-indent/adapt-indentation 
entries
   new  1c0ce74   NEWS: Remove quote from in front of headline-data symbol
   new  f03cba1   Merge branch 'maint'


Summary of changes:
 contrib/lisp/org-choose.el |  36 ++---
 etc/ORG-NEWS   |  68 
 lisp/org-agenda.el |  10 ++--
 lisp/org-mouse.el  | 130 ++---
 lisp/ox-beamer.el  |   2 +-
 lisp/ox.el |   2 +-
 6 files changed, 124 insertions(+), 124 deletions(-)
diff --git a/test/tramp-tests.el b/test/tramp-tests.el
index 719e97d..3189fa1 100644
--- a/test/tramp-tests.el
+++ b/test/tramp-tests.el
@@ -2824,9 +2824,10 @@ This tests also `file-directory-p' and 
`file-accessible-directory-p'."
  (should (file-exists-p (expand-file-name "bla" tmp-name2)))
  (should-error
   (delete-directory tmp-name1 nil 'trash)
-  ;; tramp-rclone.el calls the local `delete-directory'.
-  ;; This raises another error.
-  :type (if (tramp--test-rclone-p) 'error 'file-error))
+  ;; tramp-rclone.el and tramp-sshfs.el call the local
+  ;; `delete-directory'.  This raises another error.
+  :type (if (or (tramp--test-rclone-p) (tramp--test-sshfs-p))
+'error 'file-error))
  (delete-directory tmp-name1 'recursive 'trash)
  (should-not (file-directory-p tmp-name1))
  (should
@@ -3254,8 +3255,8 @@ This tests also `file-directory-p' and 
`file-accessible-directory-p'."
(ignore-errors (delete-directory tmp-name1 'recursive))
 
 ;; Method "smb" supports `make-symbolic-link' only if the remote host
 ;; has CIFS capabilities.  tramp-adb.el, tramp-gvfs.el and
 ;; tramp-rclone.el do not support symbolic links at all.
 (defmacro tramp--test-ignore-make-symbolic-link-error (&rest body)
   "Run BODY, ignoring \"make-symbolic-link not supported\" file error."
   (declare (indent defun) (debug (body)))
@@ -3536,7 +3537,7 @@ They might differ only in time attributes or directory 
size."
 This tests also `file-executable-p', `file-writable-p' and `set-file-modes'."
   (skip-unless (tramp--test-enabled))
   (skip-unless
-   (or (tramp--test-sh-p) (tramp--test-sudoedit-p)
+   (or (tramp--test-sh-p) (tramp--test-sshfs-p) (tramp--test-sudoedit-p)
;; Not all tramp-gvfs.el methods support changing the file mode.
(and
(tramp--test-gvfs-p)
@@ -4367,11 +4368,15 @@ This tests also `make-symbolic-link', `file-truename' 
and `add-name-to-file'."
  (and (featurep 'tramp-test-load) (unload-feature 'tramp-test-load))
  (delete-file tmp-name))
 
+(defun tramp--test-shell-file-name ()
+  "Return default remote shell.."
+  (if (tramp--test-adb-p) "/system/bin/sh" "/bin/sh"))
+
 (ert-deftest tramp-test28-process-file ()
   "Check `process-file'."
   :tags '(:expensive-test)
   (skip-unless (tramp--test-enabled))
-  (skip-unless (or (tramp--test-adb-p) (tramp--test-sh-p)))
+  (skip-unless (or (tramp--test-adb-p) (tramp--test-sh-p) 
(tramp--test-sshfs-p)))
   (skip-unless (not (tramp--test-crypt-p)))
 
   (dolist (quoted (if (tramp--test-expensive-test) '(nil t) '(nil)))
@@ -4388,25 +4393,27 @@ This tests also `make-symbolic-link', `file-truename' 
and `add-name-to-file'."
(should-not (zerop (process-file "binary-does-not-exist")))
;; Return exit code.
(should (= 42 (process-file
-  (if (tramp--test-adb-p) "/system/bin/sh" "/bin/sh")
+  (tramp--test-shell-file-name)
   nil nil nil "-c" "exit 42")))
;; Return exit code in case the process is interrupted,
;; and there's no indication for a signal describing string.
-   (let (process-file-return-signal-string)
- (should
-  (= (+ 128 2)
- (process-file
-  (if (tramp--test-adb-p) "/system/bin/sh" "/bin/sh")
-  nil nil nil "-c" "kill -2 $$"
+   (unless (tramp--test-sshfs-p)
+ (let (process-file-return-signal-string)
+   (should
+(= (+ 128 2)
+   (process-file
+(tramp--test-shell-file-name)
+nil nil nil "-c" "kill -2 $$")
;; Return string in case the process is interrupted and
  

[elpa] externals/tramp updated (373c0b5 -> 851269d)

2021-03-30 Thread Michael Albinus
albinus pushed a change to branch externals/tramp.

  from  373c0b5   Tramp ELPA version 2.5.0.2 released
   new  87c337e   * Makefile (sync): Add tramp-fuse.el and tramp-sshfs.el.
   new  851269d   Tramp ELPA version 2.5.0.3 released


Summary of changes:
 Makefile |   2 +
 test/tramp-tests.el  |  84 ++-
 texi/tramp.texi  | 303 --
 texi/trampver.texi   |   2 +-
 tramp-adb.el |   2 -
 tramp-cache.el   |  28 ++--
 tramp-cmds.el|  17 ++-
 tramp-compat.el  |   2 +-
 tramp-crypt.el   |  24 +++
 tramp-fuse.el| 205 ++
 tramp-gvfs.el|   1 -
 tramp-integration.el |  24 ++-
 tramp-rclone.el  | 189 ++--
 tramp-sh.el  | 404 ++-
 tramp-smb.el |   7 -
 tramp-sshfs.el   | 367 ++
 tramp-sudoedit.el|  22 +--
 tramp.el | 164 -
 trampver.el  |   6 +-
 19 files changed, 1189 insertions(+), 664 deletions(-)
 create mode 100644 tramp-fuse.el
 create mode 100644 tramp-sshfs.el



[elpa] externals/osc 41c6577: Support for receiving double precision (float64) values

2021-03-30 Thread Mario Lang
branch: externals/osc
commit 41c65773a75014cd32da5cf2072e6b563002bbff
Author: Mario Lang 
Commit: Mario Lang 

Support for receiving double precision (float64) values
---
 osc.el | 26 +-
 1 file changed, 25 insertions(+), 1 deletion(-)
@@ -3254,8 +3255,8 @@ This tests also `file-directory-p' and 
 
 ;; Method "smb" supports `make-symbolic-link' only if the remote host
-;; has CIFS capabilities.  tramp-adb.el, tramp-gvfs.el and
-;; tramp-rclone.el do not support symbolic links at all.
+;; has CIFS capabilities.  tramp-adb.el, tramp-gvfs.el, tramp-rclone.el
+;; and tramp-sshfs.el do not support symbolic links at all.
 (defmacro tramp--test-ignore-make-symbolic-link-error (&rest body)
   "Run BODY, ignoring \"make-symbolic-link not supported\" file error."
